"""Django Admin Advanced Search Package

This package provides advanced search functionality for Django Admin interface.
"""

__version__ = '0.1.6'
__author__ = 'shifenhutu'
__license__ = 'MIT'
__doc__ = "https://github.com/shifenhutu/django-admin-advanced-search"